import QtQuick 1.0

import "Util.js" as Util

XmlListModel {
    id: wholeModel

    property url topLargeImageUrl: count > 0 ? largeImageUrlFromSmallImageUrl(get(0).photoThumbnailUrl) : ""

    signal urlToTopLargePhotoIsReady(url url)
    signal failedToDownloadModel(string msg)

//            source: "http://api.flickr.com/services/feeds/photos_public.gne?tags=wallpaper&format=rss2"
    source: "http://api.flickr.com/services/feeds/groups_pool.gne?id=40961104@N00&lang=en-us&format=rss_200"
//            source: "../tests/testdata/localFeed.xml"
    query: "/rss/channel/item"
    namespaceDeclarations: "declare namespace media=\"http://search.yahoo.com/mrss/\";"

    XmlRole { name: "photoTitle"; query: "title/string()" }
    XmlRole { name: "photoThumbnailUrl"; query: "media:thumbnail/@url/string()" }
    XmlRole { name: "photoUrl"; query: "media:content/@url/string()" }
    XmlRole { name: "photoWidth"; query: "media:content/@width/number()" }
    XmlRole { name: "photoHeight"; query: "media:content/@height/number()" }
    XmlRole { name: "photoDescription"; query: "description/string()" }
    XmlRole { name: "photoTags"; query: "media:category/string()" }
    XmlRole { name: "photoAuthor"; query: "author/string()" }
    XmlRole { name: "photoDate"; query: "pubDate/string()" }

    function largeImageUrlFromSmallImageUrl(smallUrl) {
        return Util.urlForImageLevel(smallUrl, 2)
    }

    onStatusChanged: {
        console.log("FSM: onStatusChanged to %1".arg(status))
        if((status == XmlListModel.Ready) && (source != "")) {
            console.log('FSM: downloaded model')
            urlToTopLargePhotoIsReady(topLargeImageUrl)
        } else  if (status == XmlListModel.Error) {
            console.log("FSM: error loading. Msg is " + wholeModel.errorString())
            failedToDownloadModel(wholeModel.errorString())
        }

//        if( typeof objectToNotifyAboutLargeUrlReady != "undefined" ) {
//            console.log("FSM: objectToNotifyAboutLargeUrlReady exists, connecting")
//            objectToNotifyAboutLargeUrlReady.setWallpaper(topLargeImageUrl)
//        }
    }

    Component.onCompleted: {
        console.log("FSM: onCompleted")
        if( typeof objectToNotifyAboutLargeUrlReady != "undefined" ) {
            console.log("FSM: objectToNotifyAboutLargeUrlReady exists, connecting")
            wholeModel.urlToTopLargePhotoIsReady.connect(objectToNotifyAboutLargeUrlReady.setWallpaper)
            wholeModel.failedToDownloadModel.connect(objectToNotifyAboutLargeUrlReady.failedToDownloadModel)
        }
    }

}
