import QtQuick 1.0
import Qt.labs.components.native 1.0
import "HarmattanUiConstants.js" as UIConstants

Page {
    id: wholePage

    property bool cutCentralPartFromLandscapishImages: false

    orientationLock: PageOrientation.LockPortrait

    onOrientationLockChanged: {
        console.log("MP: orLock changed to " + orientationLock)
    }



    // @arg url _s image of the thumb clicked
    signal thumbnailClicked(string smallImageUrl, int expectedWidth, int expectedHeight)

    //for testability
    property alias feedUrl: feedModel.source
    property alias thumbnailView: thumbnailView

//    width: parent ? parent.width : 460
//    height: parent ? parent.height: 854

    TitleBar {
        id: titleBar
    }

    Rectangle {
        anchors.top: titleBar.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

//        color: "lightyellow"
        color: "lightgrey"

       FlickrSourceModel {
           id: feedModel
       }


        GridView {
            id: thumbnailView

            anchors.fill: parent
            clip: true
//            z: -10 // faster than clipping

            model: feedModel
            flow: parent.width < parent.height ? GridView.LeftToRight : GridView.TopToBottom

            cellWidth : parent.width < parent.height ? width / 2 : height / 2
            cellHeight: cellWidth
            cacheBuffer: 2*height  // half height up, half height down

            delegate:
                ThumbnailImage {
                    width: thumbnailView.cellWidth
                    height: width
                    expectedWidth: model.photoWidth
                    expectedHeight: model.photoHeight
                    wantedDetailLevel: 1
                    smallImageUrl: model.photoThumbnailUrl
                    cutCentralPartFromLandscapishImages: wholePage.cutCentralPartFromLandscapishImages

                    onClicked: wholePage.thumbnailClicked(smallImageUrl, expectedWidth, expectedHeight)
                }


        }

    }

    function updateCuttingSettingFromDb() {
        if(typeof wallpaperChanger != "undefined") {
            // no wallpaper changer in the test environment
            cutCentralPartFromLandscapishImages = wallpaperChanger.getCutCentralPartSettingFromDb()
        }
    }

    onStatusChanged: {
        if(status == PageStatus.Activating) {
            console.log("MP: activating page")
            updateCuttingSettingFromDb()
        }
    }

    Component.onCompleted: {
        console.log("MP completed. orLock is " + wholePage.orientationLock)
        console.log("MP completed. Screen or is " + screen.currentOrientation)
        console.log("MP completed. B4: Screen allowed ors are " + screen.allowedOrientation)
//        screen.allowedOrientation = Screen.Portrait
        console.log("MP completed. After: Screen allowed ors are " + screen.allowedOrientation)
    }

}
