import QtQuick 1.0
//import Qt.labs.components.native 1.0
import com.nokia.meego 1.0
import "HarmattanUiConstants.js" as UIConstants
import "Util.js" as Util

Page {
    id: wholePage

    orientationLock: PageOrientation.LockPortrait

    width: parent ? parent.width : 480
    height: parent ? parent.height: 844

//    property bool cutCentralPartOfWideImages

    TitleBar {
        id: titleBar
    }

    Rectangle {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: titleBar.bottom
        anchors.bottom: parent.bottom

        color: "lightgrey"
        Column {
            spacing: 10
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.margins: 10

            Row {
                Switch {
                    id: autoupdateStatus
                    checked: true

                    onCheckedChanged: {
                        if(typeof wallpaperChanger != "undefined") {
                            wallpaperChanger.updateAutomaticallySettingChanged(checked)
                        }
                    }
                }
                Text {
                    anchors.leftMargin: UIConstants.MARGIN_XLARGE
                    wrapMode: "WordWrap"
                    width: window.width-50
                    text: "Update wallpaper automatically"
                    verticalAlignment: Text.AlignVCenter

                    font.pixelSize: UIConstants.FONT_DEFAULT
                    color: UIConstants.COLOR_FOREGROUND
                }
            }

            Row {
                Text {
                    text: Util.allowedIntervalNames[scheduleSlider.value][0]
                    y: 10
                    x: 55
                    font.pixelSize: UIConstants.FONT_DEFAULT
                    color: autoupdateStatus.checked ? UIConstants.COLOR_FOREGROUND :
                                                      UIConstants.COLOR_DISABLED_FOREGROUND
                }
            }
            Row {
                //                Image {
                //                    //source: "../../icons/schedule-low-end.png"
                //                }
                Slider {
                    id: scheduleSlider
                    //                    anchors.left: parent.left
                    //                    anchors.right: parent.right
                    //                    y: -10
                    //                    width: window.width-100
                    enabled: autoupdateStatus.checked

                    minimumValue: 0
                    maximumValue: Util.allowedIntervalNames.length-1
                    stepSize: 1

                    onValueChanged: {
                        if(typeof wallpaperChanger != "undefined") {
                            wallpaperChanger.hoursToWaitBetweenChangesSettingChanged(
                                        Util.allowedIntervalNames[value][1] )
                        }
                    }
                }
                Image {
                    //source: "../../icons/schedule-right-end.png"
                }
            }

            Text {
                text: "What to do with the wide images?"
                font.pixelSize: UIConstants.FONT_DEFAULT
                color: UIConstants.COLOR_FOREGROUND
            }
            ButtonColumn {
                exclusive: true
                RadioButton {
                    id: rotatingSetting
                    text: 'Rotate them'
                }
                RadioButton {
                    id: cuttingSetting
                    text: 'Just cut the central part'
                }

                onCheckedButtonChanged: {
                    wallpaperChanger.updateCutCentralPartSettingChanged(cuttingSetting.checked)
                }
            }




        }


    }

    function sliderValueFromNumberOfHours(hours) {
        console.log("SP: sliderValueFromNumberOfHours: %1".arg(hours))
        var smallestDifference = Math.abs(hours - Util.allowedIntervalNames[0][1])
        var bestIndex = 0
        for(var i=0; i<Util.allowedIntervalNames.length; i++) {
            if(Math.abs(hours - Util.allowedIntervalNames[i][1]) < smallestDifference) {
                smallestDifference = Math.abs(hours - Util.allowedIntervalNames[i][1])
                bestIndex = i
            }
        }
        console.log("SP: smallestDifference found is " + smallestDifference)
        console.log("SP: bestIndex is " + bestIndex)
        return bestIndex
    }

    function fetchValuesFromDb() {
        if(typeof wallpaperChanger != "undefined") {
            // no wallpaper changer in the test environment
            autoupdateStatus.checked = wallpaperChanger.getAutoupdateStatusFromDb()
            scheduleSlider.value = sliderValueFromNumberOfHours(wallpaperChanger.getHoursToWaitBetweenUpdatesFromDb())
            setCutCentralPartOfWideImages(wallpaperChanger.getCutCentralPartSettingFromDb())
        }
    }

    function setCutCentralPartOfWideImages(newValue) {
        if(newValue)
            cuttingSetting.checked = true
        else
            rotatingSetting.checked = true
    }

    Component.onCompleted: {
        fetchValuesFromDb();
    }
}
