import QtQuick 1.0
import "Util.js" as Util


// loads _s image and right after it's loaded, loads _m one
Item {
    id: wholeThumbnail

    // 0 loads small one only, 1 adds medium, 2 adds large
    property int wantedDetailLevel: 0

    // if true, landscapish images become portraitish by cutting just the central part out
    // if false, landscapish images are rotated
    property bool cutCentralPartFromLandscapishImages: false

    // and medium image load starts loading after this signal is sent
    signal smallImageLoaded
    signal mediumImageLoaded
    signal largeImageLoaded
    // @arg url _s image of the thumb clicked
    signal clicked(string smallImageUrl, int expectedWidth, int expectedHeight)


    // set it to _s image to start loading. _m url will be generated automatically
    property string smallImageUrl: ""

    // to be filled by clients so that already by the moment of the square _s.jpg
    // load we knew the final expected dimensions
    property int expectedWidth: 0
    property int expectedHeight: 0

    // internal
    property bool sourceIsLandscapish: expectedWidth > expectedHeight

    onSmallImageUrlChanged: {
//        console.log("TI: smallImageUrl changed to " + smallImageUrl)
        // @TODO Check if repeater can destroy items, then replace 3 with wantedDetailLevel
        for(var i=0; i < 3; i++) {  // 3 because wantedDetailLevel may have decreased
            if((getImageForLevel(i)) && (getImageForLevel(i).source)) getImageForLevel(i).source = ""
        }

        if(getImageForLevel(0).source) getImageForLevel(0).source = smallImageUrl
    }

    Repeater {
        model: wantedDetailLevel+1

        Image {
            source: model.index == 0 ? urlForImageLevel(smallImageUrl, model.index) : ""
//            anchors.fill: parent
//            anchors.top: parent.top
//            anchors.left: parent.left
            width: shouldRotate() ? wholeThumbnail.height: wholeThumbnail.width
            height: shouldRotate() ? wholeThumbnail.width: wholeThumbnail.height
            fillMode: Image.PreserveAspectCrop
            clip: true
            smooth: true
            opacity: model.index == 0 ? 1 : progress
            property bool rotated: shouldRotate()

            transformOrigin: Item.BottomRight
            transform: [
                Rotation {
                    angle: shouldRotate() ? 90 : 0
                    origin.x: 0 // width / 2
                    origin.y: 0 // height / 2
                },
                Translate {
                    x: shouldRotate() ? wholeThumbnail.width : 0
                }

            ]


            onStatusChanged: {
                if((status == Image.Ready) ){
//                    console.log("TI: sourceIsLandscapish: " + sourceIsLandscapish)
//                    console.log("TI: expW x expH: %1 x %2".arg(expectedWidth).arg(expectedHeight))
//                    console.log("TI: image loaded for level " + model.index)
                    emitLoadedSignalForLevel(model.index)
                    // image may not exist if delegate was just destroyed
                    if((wantedDetailLevel > model.index) && (getImageForLevel(model.index + 1).source)){
                        getImageForLevel(model.index + 1).source = urlForImageLevel(smallImageUrl, model.index + 1)
                    }
                }
            }
        }
    }


    // @return Image element for the given detail level
    function getImageForLevel(detailLevel) {
        return wholeThumbnail.children[detailLevel]
    }

    // emits small/medium/largeImageLoaded
    function emitLoadedSignalForLevel(detailLevel) {
//        console.log("TI: signaling loaded for level " + detailLevel)
        switch(detailLevel) {
        case 0:
            smallImageLoaded()
            break
        case 1:
            mediumImageLoaded()
            break
        case 2:
            largeImageLoaded()
            break
        }
    }



    MouseArea {
        anchors.fill: parent
        onClicked: {
            parent.clicked(smallImageUrl, expectedWidth, expectedHeight)
        }
    }

    // makes an _m url out of _s one (or any ther one ending with _x.jpg
    // @return sourceUrl, but with _m
    function mediumUrlFromAnyOther(sourceUrl) {
        var res = urlForImageLevel(sourceUrl, 1)

        return res
    }


    // makes an _s, _m, or _b url out of _s one (or any ther one ending with _x.jpg
    // @arg detailLevel: accepts 0, 1 or 2. 0 - thumbnail, 1 - medium, 2 - 1024px (longest size)
    // @return sourceUrl, but with _s, _m oe _b
    function urlForImageLevel(sourceUrl, detailLevel) {
        return Util.urlForImageLevel(sourceUrl, detailLevel)
    }

    // @return true if combination of settings and image sizes indicate that
    //              image should be rotated
    //         false otherwise
    function shouldRotate() {
        var shouldCut = sourceIsLandscapish && cutCentralPartFromLandscapishImages
        var res = !shouldCut && sourceIsLandscapish
//        console.log('TI: shouldRotate: cutCentralPartFromLandscapishImages is ' + cutCentralPartFromLandscapishImages)
//        console.log('TI: shouldRotate: sourceIsLandscapish is ' + sourceIsLandscapish)
//        console.log('TI: calculated shouldRotate as ' + res)
        return res
    }

}
